summaryrefslogtreecommitdiffstats
path: root/lib/private/DB/QueryBuilder/ExpressionBuilder/ExpressionBuilder.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/private/DB/QueryBuilder/ExpressionBuilder/ExpressionBuilder.php')
-rw-r--r--lib/private/DB/QueryBuilder/ExpressionBuilder/ExpressionBuilder.php55
1 files changed, 28 insertions, 27 deletions
diff --git a/lib/private/DB/QueryBuilder/ExpressionBuilder/ExpressionBuilder.php b/lib/private/DB/QueryBuilder/ExpressionBuilder/ExpressionBuilder.php
index d4c1a9db881..ebc7f9fb77b 100644
--- a/lib/private/DB/QueryBuilder/ExpressionBuilder/ExpressionBuilder.php
+++ b/lib/private/DB/QueryBuilder/ExpressionBuilder/ExpressionBuilder.php
@@ -33,6 +33,7 @@ use OC\DB\QueryBuilder\FunctionBuilder\FunctionBuilder;
use OC\DB\QueryBuilder\Literal;
use OC\DB\QueryBuilder\QueryFunction;
use OC\DB\QueryBuilder\QuoteHelper;
+use OCP\DB\QueryBuilder\ICompositeExpression;
use OCP\DB\QueryBuilder\IExpressionBuilder;
use OCP\DB\QueryBuilder\ILiteral;
use OCP\DB\QueryBuilder\IParameter;
@@ -80,7 +81,7 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @return \OCP\DB\QueryBuilder\ICompositeExpression
*/
- public function andX(...$x) {
+ public function andX(...$x): ICompositeExpression {
$compositeExpression = call_user_func_array([$this->expressionBuilder, 'andX'], $x);
return new CompositeExpression($compositeExpression);
}
@@ -99,7 +100,7 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @return \OCP\DB\QueryBuilder\ICompositeExpression
*/
- public function orX(...$x) {
+ public function orX(...$x): ICompositeExpression {
$compositeExpression = call_user_func_array([$this->expressionBuilder, 'orX'], $x);
return new CompositeExpression($compositeExpression);
}
@@ -115,7 +116,7 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @return string
*/
- public function comparison($x, $operator, $y, $type = null) {
+ public function comparison($x, string $operator, $y, $type = null): string {
$x = $this->helper->quoteColumnName($x);
$y = $this->helper->quoteColumnName($y);
return $this->expressionBuilder->comparison($x, $operator, $y);
@@ -138,7 +139,7 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @return string
*/
- public function eq($x, $y, $type = null) {
+ public function eq($x, $y, $type = null): string {
$x = $this->helper->quoteColumnName($x);
$y = $this->helper->quoteColumnName($y);
return $this->expressionBuilder->eq($x, $y);
@@ -160,7 +161,7 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @return string
*/
- public function neq($x, $y, $type = null) {
+ public function neq($x, $y, $type = null): string {
$x = $this->helper->quoteColumnName($x);
$y = $this->helper->quoteColumnName($y);
return $this->expressionBuilder->neq($x, $y);
@@ -182,7 +183,7 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @return string
*/
- public function lt($x, $y, $type = null) {
+ public function lt($x, $y, $type = null): string {
$x = $this->helper->quoteColumnName($x);
$y = $this->helper->quoteColumnName($y);
return $this->expressionBuilder->lt($x, $y);
@@ -204,7 +205,7 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @return string
*/
- public function lte($x, $y, $type = null) {
+ public function lte($x, $y, $type = null): string {
$x = $this->helper->quoteColumnName($x);
$y = $this->helper->quoteColumnName($y);
return $this->expressionBuilder->lte($x, $y);
@@ -226,7 +227,7 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @return string
*/
- public function gt($x, $y, $type = null) {
+ public function gt($x, $y, $type = null): string {
$x = $this->helper->quoteColumnName($x);
$y = $this->helper->quoteColumnName($y);
return $this->expressionBuilder->gt($x, $y);
@@ -248,7 +249,7 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @return string
*/
- public function gte($x, $y, $type = null) {
+ public function gte($x, $y, $type = null): string {
$x = $this->helper->quoteColumnName($x);
$y = $this->helper->quoteColumnName($y);
return $this->expressionBuilder->gte($x, $y);
@@ -257,11 +258,11 @@ class ExpressionBuilder implements IExpressionBuilder {
/**
* Creates an IS NULL expression with the given arguments.
*
* @param string $x The field in string format to be restricted by IS NULL.
*
* @return string
*/
- public function isNull($x) {
+ public function isNull($x): string {
$x = $this->helper->quoteColumnName($x);
return $this->expressionBuilder->isNull($x);
}
@@ -269,11 +270,11 @@ class ExpressionBuilder implements IExpressionBuilder {
/**
* Creates an IS NOT NULL expression with the given arguments.
*
* @param string $x The field in string format to be restricted by IS NOT NULL.
*
* @return string
*/
- public function isNotNull($x) {
+ public function isNotNull($x): string {
$x = $this->helper->quoteColumnName($x);
return $this->expressionBuilder->isNotNull($x);
}
@@ -288,7 +289,7 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @return string
*/
- public function like($x, $y, $type = null) {
+ public function like($x, $y, $type = null): string {
$x = $this->helper->quoteColumnName($x);
$y = $this->helper->quoteColumnName($y);
return $this->expressionBuilder->like($x, $y);
@@ -305,7 +306,7 @@ class ExpressionBuilder implements IExpressionBuilder {
* @return string
* @since 9.0.0
*/
- public function iLike($x, $y, $type = null) {
+ public function iLike($x, $y, $type = null): string {
return $this->expressionBuilder->like($this->functionBuilder->lower($x), $this->functionBuilder->lower($y));
}
@@ -319,7 +320,7 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @return string
*/
- public function notLike($x, $y, $type = null) {
+ public function notLike($x, $y, $type = null): string {
$x = $this->helper->quoteColumnName($x);
$y = $this->helper->quoteColumnName($y);
return $this->expressionBuilder->notLike($x, $y);
@@ -335,7 +336,7 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @return string
*/
- public function in($x, $y, $type = null) {
+ public function in($x, $y, $type = null): string {
$x = $this->helper->quoteColumnName($x);
$y = $this->helper->quoteColumnNames($y);
return $this->expressionBuilder->in($x, $y);
@@ -351,7 +352,7 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @return string
*/
- public function notIn($x, $y, $type = null) {
+ public function notIn($x, $y, $type = null): string {
$x = $this->helper->quoteColumnName($x);
$y = $this->helper->quoteColumnNames($y);
return $this->expressionBuilder->notIn($x, $y);
@@ -360,22 +361,22 @@ class ExpressionBuilder implements IExpressionBuilder {
/**
* Creates a $x = '' statement, because Oracle needs a different check
*
* @param string $x The field in string format to be inspected by the comparison.
* @return string
* @since 13.0.0
*/
- public function emptyString($x) {
+ public function emptyString($x): string {
return $this->eq($x, $this->literal('', IQueryBuilder::PARAM_STR));
}
/**
* Creates a `$x <> ''` statement, because Oracle needs a different check
*
* @param string $x The field in string format to be inspected by the comparison.
* @return string
* @since 13.0.0
*/
- public function nonEmptyString($x) {
+ public function nonEmptyString($x): string {
return $this->neq($x, $this->literal('', IQueryBuilder::PARAM_STR));
}
@@ -387,7 +388,7 @@ class ExpressionBuilder implements IExpressionBuilder {
* @return IQueryFunction
* @since 12.0.0
*/
- public function bitwiseAnd($x, $y) {
+ public function bitwiseAnd($x, int $y): IQueryFunction {
return new QueryFunction($this->connection->getDatabasePlatform()->getBitAndComparisonExpression(
$this->helper->quoteColumnName($x),
$y
@@ -402,7 +403,7 @@ class ExpressionBuilder implements IExpressionBuilder {
* @return IQueryFunction
* @since 12.0.0
*/
- public function bitwiseOr($x, $y) {
+ public function bitwiseOr($x, int $y): IQueryFunction {
return new QueryFunction($this->connection->getDatabasePlatform()->getBitOrComparisonExpression(
$this->helper->quoteColumnName($x),
$y
@@ -417,7 +418,7 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @return ILiteral
*/
- public function literal($input, $type = null) {
+ public function literal($input, $type = null): ILiteral {
return new Literal($this->expressionBuilder->literal($input, $type));
}
@@ -426,9 +427,9 @@ class ExpressionBuilder implements IExpressionBuilder {
*
* @param string $column
* @param mixed $type One of IQueryBuilder::PARAM_*
- * @return string
+ * @return IQueryFunction
*/
- public function castColumn($column, $type) {
+ public function castColumn(string $column, $type): IQueryFunction {
return new QueryFunction(
$this->helper->quoteColumnName($column)
);
@@ -257,11 +258,11 @@ class ExpressionBuilder implements IExpressionBuilder {
* Creates an IS NULL expression with the given arguments.
*
- * @param string $x The field in string format to be restricted by IS NULL.
+ * @param string|ILiteral|IParameter|IQueryFunction $x The field in string format to be restricted by IS NULL.
*
* @return string
@@ -269,11 +270,11 @@ class ExpressionBuilder implements IExpressionBuilder {
* Creates an IS NOT NULL expression with the given arguments.
*
- * @param string $x The field in string format to be restricted by IS NOT NULL.
+ * @param string|ILiteral|IParameter|IQueryFunction $x The field in string format to be restricted by IS NOT NULL.
*
* @return string
@@ -360,22 +361,22 @@ class ExpressionBuilder implements IExpressionBuilder {
* Creates a $x = '' statement, because Oracle needs a different check
*
- * @param string $x The field in string format to be inspected by the comparison.
+ * @param string|ILiteral|IParameter|IQueryFunction $x The field in string format to be inspected by the comparison.
* @return string
* @since 13.0.0
@@ -360,22 +361,22 @@ class ExpressionBuilder implements IExpressionBuilder {
* Creates a `$x <> ''` statement, because Oracle needs a different check
*
- * @param string $x The field in string format to be inspected by the comparison.
+ * @param string|ILiteral|IParameter|IQueryFunction $x The field in string format to be inspected by the comparison.
* @return string
* @since 13.0.0